scoretools
==========

.. automodule:: abjad.tools.scoretools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.scoretools.GrandStaff.GrandStaff.GrandStaff
      ~abjad.tools.scoretools.InstrumentationSpecifier.InstrumentationSpecifier.InstrumentationSpecifier
      ~abjad.tools.scoretools.Performer.Performer.Performer
      ~abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory
      ~abjad.tools.scoretools.PianoStaff.PianoStaff.PianoStaff
      ~abjad.tools.scoretools.Score.Score.Score
      ~abjad.tools.scoretools.StaffGroup.StaffGroup.StaffGroup

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.scoretools.make_empty_piano_score.make_empty_piano_score
      ~abjad.tools.scoretools.make_piano_score_from_leaves.make_piano_score_from_leaves
      ~abjad.tools.scoretools.make_piano_sketch_score_from_leaves.make_piano_sketch_score_from_leaves
